@@ -327,6 +327,7 @@ getMetaFeaturesTable <- function(study, modelID, featureID) {
 #'   \item{data}{Data frame with the differential statistics to plot}
 #'   \item{highest}{(numeric) The largest differential statistic, rounded up to
 #'   the next integer}
+#'   \item{lowest}{(numeric) The lowest differential statistic, rounded down to the next integer}
 #'   \item{labelStat}{(character) The x-axis label to describe the differential
 #'   statistic}
 #'   \item{labelLow}{(character) The vertical axis label on the left to describe
@@ -440,7 +441,8 @@ getBarcodeData <- function(study, modelID, testID, annotationID, termID) {
 
   newList <- list(
     data = barcodeDataTable,
-    highest = ceiling(max(abs(barcodeDataTable[, "statistic"]))),
+    highest = ceiling(max(barcodeDataTable[, "statistic"])),
+    lowest = floor(min(barcodeDataTable[, "statistic"])),
     labelStat = barcodes[["labelStat"]],
     labelLow = barcodes[["labelLow"]],
     labelHigh = barcodes[["labelHigh"]]
